[![version badge](https://badge.fury.io/py/hyena.svg)](https://badge.fury.io/py/hyena)

**hyena** is data purifier with schema

## Warning

This repository is on developing. Some bugs may exist, possible to change suddenly. And no document yet.


## Installation

    pip install hyena-py
